@@ -4,7 +4,7 @@
  *              to build a moderately scalable and highly available server
  *              based on a cluster of servers, with more flexibility.
  *
- * Version:     $Id: tcp_vs.c,v 1.15 2003/05/23 02:51:12 wensong Exp $
+ * Version:     $Id: tcp_vs.c,v 1.15.2.1 2004/10/30 16:28:14 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *
@@ -528,11 +528,20 @@ tcp_vs_child(void *__child)
 	daemonize();
 
 	/* Block all signals except SIGKILL and SIGSTOP */
+#ifdef RH_NPTL_KLUDGE
+	spin_lock_irq(&current->sighand->siglock);
+#else
 	spin_lock_irq(&current->sigmask_lock);
+#endif
 	siginitsetinv(&current->blocked,
 		      sigmask(SIGKILL) | sigmask(SIGSTOP));
+#ifdef RH_NPTL_KLUDGE
+	recalc_sigpending();
+	spin_unlock_irq(&current->sighand->siglock);
+#else
 	recalc_sigpending(current);
 	spin_unlock_irq(&current->sigmask_lock);
+#endif
 
 	sock = svc->mainsock;
 	if (sock == NULL) {
@@ -622,11 +631,20 @@ tcp_vs_daemon(void *__svc)
 	daemonize();
 
 	/* Block all signals except SIGKILL and SIGSTOP */
+#ifdef RH_NPTL_KLUDGE
+	spin_lock_irq(&current->sighand->siglock);
+#else
 	spin_lock_irq(&current->sigmask_lock);
+#endif
 	siginitsetinv(&current->blocked,
 		      sigmask(SIGKILL) | sigmask(SIGSTOP));
+#ifdef RH_NPTL_KLUDGE
+	recalc_sigpending();
+	spin_unlock_irq(&current->sighand->siglock);
+#else
 	recalc_sigpending(current);
 	spin_unlock_irq(&current->sigmask_lock);
+#endif
 
 	if (!svc->scheduler) {
 		TCP_VS_ERR("%s's scheduler is not bound\n",
@@ -704,11 +722,20 @@ master_daemon(void *unused)
 	daemonize();
 
 	/* Block all signals except SIGKILL and SIGSTOP */
+#ifdef RH_NPTL_KLUDGE
+	spin_lock_irq(&current->sighand->siglock);
+#else
 	spin_lock_irq(&current->sigmask_lock);
+#endif
 	siginitsetinv(&current->blocked,
 		      sigmask(SIGKILL) | sigmask(SIGSTOP));
+#ifdef RH_NPTL_KLUDGE
+	recalc_sigpending();
+	spin_unlock_irq(&current->sighand->siglock);
+#else
 	recalc_sigpending(current);
 	spin_unlock_irq(&current->sigmask_lock);
+#endif
 
 	/* main loop */
 	while (sysctl_ktcpvs_unload == 0) {
