@@ -5,7 +5,7 @@
  *
  * tcp_vs.h: main structure definitions and function prototypes
  *
- * $Id: tcp_vs.h,v 1.22 2003/07/08 02:42:07 wensong Exp $
+ * $Id: tcp_vs.h,v 1.21.2.1 2004/10/30 16:28:14 wensong Exp $
  *
  */
 
@@ -14,7 +14,7 @@
 
 #include <asm/types.h>		/* For __uXX types */
 
-#define TCP_VS_VERSION_CODE		0x00000F
+#define TCP_VS_VERSION_CODE		0x00000E
 #define NVERSION(version)                       \
 	(version >> 16) & 0xFF,                 \
 	(version >> 8) & 0xFF,                  \
@@ -103,6 +103,9 @@ struct tcp_vs_rule_u {
 	/* destination server */
 	__u32 addr;
 	__u16 port;
+
+	/* special entry for hhttp module */
+	int match_num;
 };
 
 
@@ -267,6 +270,9 @@ struct tcp_vs_rule {
 	regex_t rx;
 
 	struct list_head destinations;
+
+	/* special field for hhttp module */
+	int match_num;
 };
 
 
