@@ -7,10 +7,10 @@
  * tcp_vs_chttp.c: KTCPVS content-based scheduling module for HTTP service
  *		   with cookie support.
  *
- * Version:	$Id: tcp_vs_chttp.c,v 1.6 2003/06/14 09:04:11 wensong Exp $
+ * Version:	$Id: tcp_vs_chttp.c,v 1.7 2003/06/14 16:09:47 wensong Exp $
  *
- * Authors:     Wensong Zhang, <wensong@linuxvirtualserver.org>
- *              Hai Long, <david_lung@yahoo.com>
+ * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
+ *              Hai Long <david_lung@yahoo.com>
  *
  *              This program is free software; you can redistribute it and/or
  *              modify it under the terms of the GNU General Public License
@@ -29,9 +29,13 @@
 
 #include <linux/skbuff.h>
 #include <net/sock.h>
+
 #include "tcp_vs.h"
+#include "tcp_vs_http_parser.h"
+#include "tcp_vs_http_trans.h"
 #include "avl.h"
 
+
 #define COOKIE_DISCARD_TIME	600
 
 /* cookie table entry definition */
@@ -524,7 +528,7 @@ chttp_get_response(struct socket *csock, server_conn_t * sc,
 		   int buflen, int *close)
 {
 	http_read_ctl_block_t read_ctl_blk;
-	http_buf_t	buff;	
+	http_buf_t	buff;
 	http_response_t resp;
 	int len, ret = -1;
 	struct socket *dsock = sc->sock;
@@ -658,7 +662,7 @@ xmit_http_message_header(struct socket *dsock,
 	list_for_each_safe(l, temp, &read_ctl->buf_entry_list) {
 		buf_entry = list_entry(l, http_buf_t, b_list);
 
-		if (tcp_vs_xmit(dsock, buf_entry->buf, 
+		if (tcp_vs_xmit(dsock, buf_entry->buf,
 				buf_entry->data_len, MSG_MORE) < 0) {
 			TCP_VS_ERR("Error in xmitting message header\n");
 			ret = -1;
