@@ -4,7 +4,7 @@
  *              to build a moderately scalable and highly available server
  *              based on a cluster of servers, with more flexibility.
  *
- * Version:     $Id: tcp_vs_ctl.c,v 1.13 2003/05/23 06:56:14 wensong Exp $
+ * Version:     $Id: tcp_vs_ctl.c,v 1.13.2.1 2004/10/30 16:28:14 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *
@@ -272,7 +272,7 @@ tcp_vs_del_dest(struct tcp_vs_service *svc, __u32 daddr, __u16 dport)
 
 static int
 tcp_vs_add_rule(struct tcp_vs_service *svc,
-		char *pattern, __u32 addr, __u16 port)
+		char *pattern, int matchnum, __u32 addr, __u16 port)
 {
 	tcp_vs_dest_t *dest;
 	struct tcp_vs_rule *r;
@@ -320,7 +320,7 @@ tcp_vs_add_rule(struct tcp_vs_service *svc,
 	memset(r, 0, sizeof(struct tcp_vs_rule));
 	INIT_LIST_HEAD(&r->destinations);
 
-	if (regcomp(&r->rx, pattern, REG_EXTENDED | REG_NOSUB)) {
+	if (regcomp(&r->rx, pattern, REG_EXTENDED)) {
 		TCP_VS_ERR("pattern compiling failed\n");
 		kfree(r);
 		rc = -EFAULT;
@@ -329,6 +329,7 @@ tcp_vs_add_rule(struct tcp_vs_service *svc,
 
 	r->pattern = strdup(pattern);
 	r->len = strlen(pattern);
+	r->match_num = matchnum;
 	list_add(&dest->r_list, &r->destinations);
 
 	/* add this new rule to rule_list finally */
@@ -736,7 +737,7 @@ do_tcp_vs_set_ctl(struct sock *sk, int cmd, void *user, unsigned int len)
 		break;
 
 	case TCP_VS_SO_SET_ADDRULE:
-		ret = tcp_vs_add_rule(svc, rule->pattern,
+		ret = tcp_vs_add_rule(svc, rule->pattern, rule->match_num,
 				      rule->addr, rule->port);
 		break;
 
@@ -872,6 +873,7 @@ __tcp_vs_get_rule_entries(const struct tcp_vs_get_rules *get,
 			dest = list_entry(e, tcp_vs_dest_t, r_list);
 			strcpy(entry.pattern, rule->pattern);
 			entry.len = rule->len;
+			entry.match_num = rule->match_num;
 			entry.addr = dest->addr;
 			entry.port = dest->port;
 			if (copy_to_user(&uptr->entrytable[count],
