@@ -7,10 +7,10 @@
  * tcp_vs_phttp.c: KTCPVS content-based scheduling module for HTTP service
  *		   with persistent connection support.
  *
- * Version:     $Id: tcp_vs_phttp.c,v 1.11 2003/06/14 09:04:11 wensong Exp $
+ * Version:     $Id: tcp_vs_phttp.c,v 1.13 2003/07/08 02:09:13 wensong Exp $
  *
- * Authors:     Wensong Zhang, <wensong@linuxvirtualserver.org>
- *              Hai Long, <david_lung@yahoo.com>
+ * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
+ *              Hai Long <david_lung@yahoo.com>
  *
  *              This program is free software; you can redistribute it and/or
  *              modify it under the terms of the GNU General Public License
@@ -29,7 +29,11 @@
 
 #include <linux/skbuff.h>
 #include <net/sock.h>
+
 #include "tcp_vs.h"
+#include "tcp_vs_http_parser.h"
+#include "tcp_vs_http_trans.h"
+
 
 static int
 tcp_vs_phttp_init_svc(struct tcp_vs_service *svc)
@@ -273,8 +277,8 @@ tcp_vs_phttp_schedule(struct tcp_vs_conn *conn, struct tcp_vs_service *svc)
 	do {
 		switch (data_available(&read_ctl_blk)) {
 		case -1:
-			TCP_VS_DBG(5,
-				   "Socket error before reading request line.\n");
+			TCP_VS_DBG(5, "Socket error before reading "
+				   "request line.\n");
 			ret = -2;
 			goto out;
 
@@ -311,8 +315,7 @@ tcp_vs_phttp_schedule(struct tcp_vs_conn *conn, struct tcp_vs_service *svc)
 		/* read request line from client socket */
 		len = http_read_line(&read_ctl_blk, 0);
 		if (len < 0) {
-			TCP_VS_ERR
-			    ("Error reading request line from client\n");
+			TCP_VS_ERR("Error reading request line from client\n");
 			ret = -2;
 			goto out;
 		}
@@ -396,8 +399,8 @@ tcp_vs_phttp_schedule(struct tcp_vs_conn *conn, struct tcp_vs_service *svc)
 			if (tcp_vs_recvbuffer(conn->csock,
 					      read_ctl_blk.cur_buf->buf,
 					      len + 2, 0) != (len + 2)) {
-				TCP_VS_ERR
-				    ("Error in re-reading http request line\n");
+				TCP_VS_ERR("Error in re-reading http "
+					   "request line\n");
 				tcp_vs_srvconn_put(sc);
 				goto out;
 			}
@@ -422,8 +425,7 @@ tcp_vs_phttp_schedule(struct tcp_vs_conn *conn, struct tcp_vs_service *svc)
 			if (tcp_vs_xmit
 			    (dsock, read_ctl_blk.info, len + 2,
 			     MSG_MORE) < 0) {
-				TCP_VS_ERR
-				    ("Error in sending MIME header\n");
+				TCP_VS_ERR("Error in sending MIME header\n");
 				goto out_free;
 			}
 
@@ -453,7 +455,7 @@ tcp_vs_phttp_schedule(struct tcp_vs_conn *conn, struct tcp_vs_service *svc)
 	} while (req.mime.connection_close != 1);
 
       out:
-	http_read_free(&read_ctl_blk);      	
+	http_read_free(&read_ctl_blk);
 	LeaveFunction(5);
 	return ret;
 
