@@ -1,7 +1,7 @@
 /*
  *      tcpvsadm - TCP Virtual Server ADMinistration program
  *
- *      Version: $Id: tcpvsadm.c,v 1.12 2003/05/23 02:08:34 wensong Exp $
+ *      Version: $Id: tcpvsadm.c,v 1.12.2.2 2004/10/31 04:06:19 wensong Exp $
  *
  *      Authors: Wensong Zhang <wensong@linuxvirtualserver.org>
  *
@@ -51,7 +51,7 @@
 #include "libtcpvs/libtcpvs.h"
 
 static const char *program;
-#define TCPVSADM_VERSION_DATE	"22-Feb-2003"
+#define TCPVSADM_VERSION_DATE	"31-Oct-2004"
 static const char *program_version = VERSION ", " TCPVSADM_VERSION_DATE;
 
 /* default scheduler */
@@ -113,7 +113,9 @@ static const char *cmdnames[] = {
 #define OPT_REALSERVER	0x00020
 #define OPT_WEIGHT	0x00040
 #define OPT_PATTERN	0x00080
-#define NUMBER_OF_OPT	9
+#define OPT_MATCHNUM	0x00100
+#define OPT_LISTEN	0x00200
+#define NUMBER_OF_OPT	11
 
 static const char *optnames[] = {
 	"numeric",
@@ -124,6 +126,8 @@ static const char *optnames[] = {
 	"real-server",
 	"weight",
 	"pattern",
+	"match",
+	"listen",
 };
 
 /*
@@ -135,20 +139,20 @@ static const char *optnames[] = {
  *  ' '  optional
  */
 static const char commands_v_options[NUMBER_OF_CMD][NUMBER_OF_OPT] = {
-/*             -n   -i   -s   ads  prt  -r   -w   -p */
-/*ADD*/       {'x', '+', ' ', ' ', ' ', 'x', 'x', 'x'},
-/*EDIT*/      {'x', '+', ' ', ' ', ' ', 'x', 'x', 'x'},
-/*DEL*/       {'x', '+', 'x', 'x', 'x', 'x', 'x', 'x'},
-/*FLUSH*/     {'x', 'x', 'x', 'x', 'x', 'x', 'x', 'x'},
-/*LIST*/      {' ', ' ', 'x', 'x', 'x', 'x', 'x', 'x'},
-/*ADD-SERVER*/{'x', '+', 'x', 'x', 'x', '+', ' ', 'x'},
-/*DEL-SERVER*/{'x', '+', 'x', 'x', 'x', '+', 'x', 'x'},
-/*EDIT-SRV*/  {'x', '+', 'x', 'x', 'x', '+', ' ', 'x'},
-/*ADD-RULE*/  {'x', '+', 'x', 'x', 'x', '+', 'x', '+'},
-/*DEL-RULE*/  {'x', '+', 'x', 'x', 'x', '+', 'x', '+'},
-/*START*/     {'x', '1', 'x', 'x', 'x', 'x', 'x', 'x'},
-/*STOP*/      {'x', '1', 'x', 'x', 'x', 'x', 'x', 'x'},
-/*LOAD-CF*/   {'x', 'x', 'x', 'x', 'x', 'x', 'x', 'x'},
+/*             -n   -i   -s   ads  prt  -r   -w   -p   -m   -l */
+/*ADD*/       {'x', '+', ' ', ' ', ' ', 'x', 'x', 'x', 'x', ' '},
+/*EDIT*/      {'x', '+', ' ', ' ', ' ', 'x', 'x', 'x', 'x', 'x'},
+/*DEL*/       {'x', '+', 'x', 'x', 'x', 'x', 'x', 'x', 'x', 'x'},
+/*FLUSH*/     {'x', 'x', 'x', 'x', 'x', 'x', 'x', 'x', 'x', 'x'},
+/*LIST*/      {' ', ' ', 'x', 'x', 'x', 'x', 'x', 'x', 'x', 'x'},
+/*ADD-SERVER*/{'x', '+', 'x', 'x', 'x', '+', ' ', 'x', 'x', 'x'},
+/*DEL-SERVER*/{'x', '+', 'x', 'x', 'x', '+', 'x', 'x', 'x', 'x'},
+/*EDIT-SRV*/  {'x', '+', 'x', 'x', 'x', '+', ' ', 'x', 'x', 'x'},
+/*ADD-RULE*/  {'x', '+', 'x', 'x', 'x', '+', 'x', '+', ' ', 'x'},
+/*DEL-RULE*/  {'x', '+', 'x', 'x', 'x', '+', 'x', '+', 'x', 'x'},
+/*START*/     {'x', '1', 'x', 'x', 'x', 'x', 'x', 'x', 'x', 'x'},
+/*STOP*/      {'x', '1', 'x', 'x', 'x', 'x', 'x', 'x', 'x', 'x'},
+/*LOAD-CF*/   {'x', 'x', 'x', 'x', 'x', 'x', 'x', 'x', 'x', 'x'},
 };
 
 static struct option long_options[] = {
@@ -157,6 +161,7 @@ static struct option long_options[] = {
 	{"delete-service", 0, 0, 'D'},
 	{"flush", 0, 0, 'F'},
 	{"list", 0, 0, 'L'},
+	{"virtual-server", 0, 0, 'V'},
 	{"add-server", 0, 0, 'a'},
 	{"edit-server", 0, 0, 'e'},
 	{"delete-server", 0, 0, 'd'},
@@ -171,6 +176,7 @@ static struct option long_options[] = {
 	{"real-server", 1, 0, 'r'},
 	{"weight", 1, 0, 'w'},
 	{"pattern", 1, 0, 'p'},
+	{"match", 1, 0, 'm'},
 	{"numeric", 0, 0, 'n'},
 	{"load-configfile", 1, 0, 'f'},
 	{0, 0, 0, 0}
@@ -180,7 +186,7 @@ static struct option long_options[] = {
 int
 main(int argc, char **argv)
 {
-	const char *optstring = "AEDFaedLlf:hi:s:P:r:p:n";
+	const char *optstring = "AEDFaedLlf:hi:s:P:V:r:p:m:n";
 	int c, parse;
 	char cf[128];
 	unsigned int command = CMD_NONE;
@@ -262,7 +268,6 @@ main(int argc, char **argv)
 		set_command(&command, CMD_STOP);
 		break;
 	case 'L':
-	case 'l':
 		set_command(&command, CMD_LIST);
 		break;
 	case 'f':
@@ -296,6 +301,13 @@ main(int argc, char **argv)
 				fail(2, "illegal server port specified");
 			conf.port = htons(parse);
 			break;
+		case 'l':
+			set_option(&options, OPT_LISTEN);
+			parse = parse_addrport(optarg, IPPROTO_TCP,
+					       &conf.addr, &conf.port);;
+			if (parse == 0)
+				fail(2, "illegal address:port specified");
+			break;
 		case 'r':
 			set_option(&options, OPT_REALSERVER);
 			parse = parse_addrport(optarg, IPPROTO_TCP,
@@ -315,6 +327,13 @@ main(int argc, char **argv)
 				KTCPVS_PATTERN_MAXLEN);
 			rule.len = strlen(optarg);
 			break;
+		case 'm':
+			set_option(&options, OPT_MATCHNUM);
+			parse = string_to_number(optarg, 0, 10);
+			if (parse == -1) 
+				fail(2, "illegal match number specified");
+			rule.match_num = parse;
+			break;
 		case 'n':
 			set_option(&options, OPT_NUMERIC);
 			format |= FMT_NUMERIC;
@@ -517,8 +536,11 @@ print_service(struct tcp_vs_service_u *svc, unsigned int format)
 						  IPPROTO_TCP, format)))
 			fail(2, "addrport_to_anyname: %s",
 			     strerror(errno));
-		printf("    rule = pattern \"%s\" use server %s\n",
-		       e->pattern, dname);
+		printf("    rule = pattern \"%s\" ",
+		       e->pattern);
+		if (!strcasecmp(svc->conf.sched_name, "hhttp"))
+			printf("match %d ", e->match_num);
+		printf("use server %s\n", dname);
 		free(dname);
 	}
 
@@ -650,14 +672,14 @@ usage_exit(const int status)
 	fprintf(stream,
 		"%s %s\n"
 		"Usage:\n"
-		"  %s -A|E -i ident [-s scheduler] [-P port]\n"
+		"  %s -A|E -i ident [-s scheduler] [-P port] [-l address[:port]]\n"
 		"  %s -D -i ident\n"
 		"  %s -F\n"
 		"  %s -a|e -i ident -r server-address [-w weight]\n"
 		"  %s -d -i ident -r server-address\n"
-		"  %s --add-rule -i ident -p pattern -r server-address\n"
+		"  %s --add-rule -i ident -p pattern -r server-address [-m match-num]\n"
 		"  %s --del-rule -i ident -p pattern -r server-address\n"
-		"  %s -L|l [-n]\n"
+		"  %s -L [-n]\n"
 		"  %s -f config-file\n"
 		"  %s --start|stop [-i ident]\n"
 		"  %s -h\n\n",
@@ -689,7 +711,9 @@ usage_exit(const int status)
 		"  --scheduler    -s scheduler         one of wlc|http\n"
 		"                                      the default scheduler is %s.\n"
 		"  --port         -p port              service port number\n"
+		"  --match        -m match-num         match number to hash (hhttp only)\n"
 		"  --real-server  -r server-address    server-address is host (and port)\n"
+		"  --virtual-server -V server-address    virtual server-address is host (and port)\n"
 		"  --weight       -w weight            capacity of real server\n"
 		"  --numeric      -n                   numeric output of addresses and ports\n",
 		DEFAULT_SCHEDULER);
